@@ -1,5 +1,7 @@
 package Selenium::Remote::ErrorHandler;
-$Selenium::Remote::ErrorHandler::VERSION = '0.18'; # TRIAL
+$Selenium::Remote::ErrorHandler::VERSION = '0.1801'; # TRIAL
+# ABSTRACT: Error handler for Selenium::Remote::Driver
+
 use Moo;
 use Carp qw(croak);
 
@@ -134,13 +136,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Selenium::Remote::ErrorHandler - Error handler for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 0.18
+version 0.1801
 
 =head1 SEE ALSO
 
@@ -152,26 +156,44 @@ L<http://code.google.com/p/selenium/>.
 The Selenium issue tracking system is available online at
 L<http://github.com/gempesaw/Selenium-Remote-Driver/issues>.
 
-=head1 CURRENT MAINTAINER
+=head1 AUTHORS
 
-Daniel Gempesaw C<< <gempesaw@gmail.com> >>
+=over 4
 
-=head1 AUTHOR
+=item *
 
-Perl Bindings for Remote Driver by Aditya Ivaturi C<< <ivaturi@gmail.com> >>
+Aditya Ivaturi <ivaturi@gmail.com>
 
-=head1 LICENSE
+=item *
+
+Daniel Gempesaw <gempesaw@gmail.com>
+
+=item *
+
+Luke Closs <cpan@5thplane.com>
+
+=item *
+
+Mark Stosberg <mark@stosberg.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
+Copyright (c) 2014 Daniel Gempesaw
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
-     http://www.apache.org/licenses/LICENSE-2.0
+http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
+
+=cut
