@@ -1,5 +1,7 @@
 package Selenium::Remote::RemoteConnection;
-$Selenium::Remote::RemoteConnection::VERSION = '0.18'; # TRIAL
+$Selenium::Remote::RemoteConnection::VERSION = '0.1801'; # TRIAL
+#ABSTRACT: Connect to a selenium server
+
 use Moo;
 use Try::Tiny;
 use LWP::UserAgent;
@@ -75,7 +77,7 @@ sub request {
     }
 
     if ((defined $params) && $params ne '') {
-        my $json = new JSON;
+        my $json = JSON->new;
         $json->allow_blessed;
         $content = $json->allow_nonref->utf8->encode($params);
     }
@@ -95,7 +97,7 @@ sub request {
 sub _process_response {
     my ($self, $response) = @_;
     my $data; # server response 'value' that'll be returned to the user
-    my $json = new JSON;
+    my $json = JSON->new;
 
     if ($response->is_redirect) {
         return $self->request('GET', $response->header('location'));
@@ -113,7 +115,7 @@ sub _process_response {
         }
 
         if ($response->is_error) {
-            my $error_handler = new Selenium::Remote::ErrorHandler;
+            my $error_handler = Selenium::Remote::ErrorHandler->new;
             $data->{'cmd_status'} = 'NOTOK';
             if (defined $decoded_json) {
                 $data->{'cmd_return'} = $error_handler->process_error($decoded_json);
@@ -149,17 +151,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Selenium::Remote::RemoteConnection - Connect to a selenium server
 
 =head1 VERSION
 
-version 0.18
+version 0.1801
 
 =head1 SEE ALSO
 
-For more information about Selenium, visit the website at
+For more information about Selenium , visit the website at
 L<http://code.google.com/p/selenium/>.
 
 =head1 BUGS
@@ -167,26 +171,44 @@ L<http://code.google.com/p/selenium/>.
 The Selenium issue tracking system is available online at
 L<http://github.com/gempesaw/Selenium-Remote-Driver/issues>.
 
-=head1 CURRENT MAINTAINER
+=head1 AUTHORS
 
-Daniel Gempesaw C<< <gempesaw@gmail.com> >>
+=over 4
 
-=head1 AUTHOR
+=item *
 
-Perl Bindings for Selenium Remote Driver by Aditya Ivaturi C<< <ivaturi@gmail.com> >>
+Aditya Ivaturi <ivaturi@gmail.com>
 
-=head1 LICENSE
+=item *
+
+Daniel Gempesaw <gempesaw@gmail.com>
+
+=item *
+
+Luke Closs <cpan@5thplane.com>
+
+=item *
+
+Mark Stosberg <mark@stosberg.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
+Copyright (c) 2014 Daniel Gempesaw
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
-     http://www.apache.org/licenses/LICENSE-2.0
+http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
+
+=cut
