@@ -1,20 +1,7 @@
 package Selenium::Remote::WDKeys;
-$Selenium::Remote::WDKeys::VERSION = '0.18'; # TRIAL
-=head1 NAME
+$Selenium::Remote::WDKeys::VERSION = '0.1801'; # TRIAL
+# ABSTRACT: Representation of keystrokes used by Selenium::Remote::WebDriver
 
-Selenium::Remote::WDKeys - Representation of keystrokes used by Selenium::Remote::WebDriver
-
-=head1 VERSION
-
-version 0.18
-
-=cut
-
-=head1 DESCRIPTION
-
-The constant KEYS is defined here.
-
-=cut
 
 
 use strict;
@@ -84,3 +71,73 @@ use constant KEYS => {
 our @EXPORT = ('KEYS');
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Selenium::Remote::WDKeys - Representation of keystrokes used by Selenium::Remote::WebDriver
+
+=head1 VERSION
+
+version 0.1801
+
+=head1 DESCRIPTION
+
+The constant KEYS is defined here.
+
+=head1 SEE ALSO
+
+For more information about Selenium , visit the website at
+L<http://code.google.com/p/selenium/>.
+
+=head1 BUGS
+
+The Selenium issue tracking system is available online at
+L<http://github.com/gempesaw/Selenium-Remote-Driver/issues>.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Aditya Ivaturi <ivaturi@gmail.com>
+
+=item *
+
+Daniel Gempesaw <gempesaw@gmail.com>
+
+=item *
+
+Luke Closs <cpan@5thplane.com>
+
+=item *
+
+Mark Stosberg <mark@stosberg.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
+
+Copyright (c) 2014 Daniel Gempesaw
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+
+=cut
