@@ -1,5 +1,7 @@
 package Test::Selenium::Remote::WebElement;
-$Test::Selenium::Remote::WebElement::VERSION = '0.18'; # TRIAL
+$Test::Selenium::Remote::WebElement::VERSION = '0.1801'; # TRIAL
+# ABSTRACT: A sub-class of L<Selenium::Remote::WebElement>, with several test-specific method additions.
+
 use parent 'Selenium::Remote::WebElement';
 use Moo;
 use Test::Builder;
@@ -179,18 +181,8 @@ sub attribute_unlike {
 
 __END__
 
-=head1 NAME
-
-Test::Selenium::Remote::WebElement
-
-=head1 VERSION
-
-version 0.18
-
 =head1 DESCRIPTION
 
-A sub-class of L<Selenium::Remote::WebElement>, with several test-specific method additions.
-
 This is an I<experimental> addition to the Selenium::Remote::Driver
 distribution, and some interfaces may change.
 
